@@ -1,30 +1,27 @@
-import os
 from pyramid import testing
 from webtest import TestApp
 from cms import main
-from cms.tests.utils import BaseTestCase
-from cms.tests.utils import RepoHelper
+from cms.tests.base import UnicoreTestCase
 
 
-class PageTestCase(BaseTestCase):
+class PageTestCase(UnicoreTestCase):
 
     def setUp(self):
         self.config = testing.setUp()
-        self.repo_path = os.path.join(os.getcwd(), '.test_repos', self.id())
+        self.workspace = self.mk_workspace()
 
         settings = {
-            'git.path': self.repo_path,
+            'git.path': self.workspace.working_dir,
+            'es.index_prefix': self.workspace.index_prefix,
             'git.content_repo_url': '',
         }
         self.app = TestApp(main({}, **settings))
 
-        self.repo = RepoHelper.read(self.repo_path)
-        self.repo.create_categories()
-        self.repo.create_pages()
+        self.category1, self.category2 = self.create_categories(self.workspace)
+        self.create_pages(self.workspace)
 
     def tearDown(self):
         testing.tearDown()
-        self.repo.destroy()
 
     def test_get_pages(self):
         resp = self.app.get('/api/pages.json', status=200)
@@ -41,24 +38,20 @@ class PageTestCase(BaseTestCase):
             'Page not found.')
 
     def test_get_pages_for_category(self):
-        models = self.repo.get_models()
-        hygiene_category = models.GitCategoryModel.filter(slug='hygiene')[0]
-        p = models.GitPageModel(
+        [page] = self.create_pages(
+            self.workspace,
+            count=1, primary_category=self.category1.uuid,
             title='Test Category Page',
-            content='this is sample content for a hygiene page',
-            primary_category=hygiene_category
-        )
-        p.save(True, message='added hygiene page')
+            content='this is sample content for a hygiene page')
 
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 3)
 
-        data = {'uuid': p.id}
-        resp = self.app.get('/api/pages/%(uuid)s.json' % data, status=200)
+        resp = self.app.get('/api/pages/%s.json' % (page.uuid,), status=200)
         self.assertEquals(resp.json['title'], 'Test Category Page')
-        self.assertEquals(resp.json['primary_category']['slug'], 'hygiene')
+        self.assertEquals(resp.json['primary_category'], self.category1.uuid)
 
-        data = {'primary_category': hygiene_category.id}
+        data = {'primary_category': self.category1.uuid}
         resp = self.app.get('/api/pages.json', data, status=200)
         self.assertEquals(len(resp.json), 1)
 
@@ -93,21 +86,19 @@ class PageTestCase(BaseTestCase):
             'content is a required field.')
 
     def test_post_page_with_category(self):
-        models = self.repo.get_models()
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 2)
 
-        hygiene_category = models.GitCategoryModel.filter(slug='hygiene')[0]
         data = {
             'title': 'New Page',
             'content': 'Sample page content',
-            'primary_category': hygiene_category.id
+            'primary_category': self.category1.uuid
         }
         resp = self.app.post_json('/api/pages.json', data, status=201)
         self.assertTrue(resp.location.endswith(
             '/api/pages/%s.json' % resp.json['uuid']))
         self.assertEquals(resp.json['title'], 'New Page')
-        self.assertEquals(resp.json['primary_category']['title'], 'Hygiene')
+        self.assertEquals(resp.json['primary_category'], self.category1.uuid)
 
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 3)
@@ -122,23 +113,20 @@ class PageTestCase(BaseTestCase):
         self.assertEquals(len(resp.json), 3)
 
     def test_put_page(self):
-        models = self.repo.get_models()
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 2)
         uuid = resp.json[0]['uuid']
 
-        diarrhoea_category = models.GitCategoryModel.filter(
-            slug='diarrhoea')[0]
         data = {
             'uuid': uuid,
             'title': 'Another New Page',
             'content': 'Another sample page content',
-            'primary_category': diarrhoea_category.id
+            'primary_category': self.category1.uuid
         }
         resp = self.app.put_json(
             '/api/pages/%s.json' % uuid, data, status=200)
         self.assertEquals(resp.json['title'], 'Another New Page')
-        self.assertEquals(resp.json['primary_category']['title'], 'Diarrhoea')
+        self.assertEquals(resp.json['primary_category'], self.category1.uuid)
 
         resp = self.app.get('/api/pages.json', status=200)
         self.assertEquals(len(resp.json), 2)
@@ -146,7 +134,7 @@ class PageTestCase(BaseTestCase):
         data = {
             'title': 'Yet Another New Page',
             'content': 'Yet Another sample page content',
-            'primary_category': diarrhoea_category.id
+            'primary_category': self.category1.uuid
         }
         resp = self.app.put_json(
             '/api/pages/some-invalid-id.json', data, status=400)
@@ -165,7 +153,7 @@ class PageTestCase(BaseTestCase):
         self.assertEquals(resp.json['uuid'], uuid)
         self.assertEquals(resp.json['title'], 'Another New Page')
         self.assertEquals(resp.json['content'], 'Another sample page content')
-        self.assertEquals(resp.json['primary_category']['title'], 'Diarrhoea')
+        self.assertEquals(resp.json['primary_category'], self.category1.uuid)
 
     def test_put_page_with_blank_category(self):
         resp = self.app.get('/api/pages.json', status=200)
